SystemOrganization addCategory: #'AL-Tests-Application'!

TestCase subclass: #ALApplicationTest
	instanceVariableNames: 'application'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AL-Tests-Application'!

!ALApplicationTest methodsFor: 'resource faking' stamp: 'cwp 4/23/2011 17:33'!
handleRequest: aRequest locator: aLocator
	^ ALResponse status: 204 reason: 'This is a test.'! !

!ALApplicationTest methodsFor: 'resource faking' stamp: 'cwp 4/23/2011 16:17'!
request: aRequest response: aResponse locator: aLocator
	aResponse status: 204 reason: 'This is a test.'! !

!ALApplicationTest methodsFor: 'tests' stamp: 'cwp 12/2/2012 19:00'!
setUp
	| locator |
	locator := ALRestfulLocator sequential.
	locator at: 'fizz' put: self.
	application := ALApplication withLocator: locator.
	application addFactory: [:relay | ALHttpExceptionRelay destination: relay].! !

!ALApplicationTest methodsFor: 'tests' stamp: 'cwp 12/2/2012 18:58'!
testHandleRequest
	| response request |
	request := ALRequest method: 'GET' url: ALUrl / 'fizz'.
	response := application createRequestHandler handleRequest: request.
	self assert: (response isKindOf: ALResponse)
! !

TestCase subclass: #ALDigestPrintingTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AL-Tests-Application'!

!ALDigestPrintingTest methodsFor: 'as yet unclassified' stamp: 'cwp 10/14/2012 00:47'!
test01
	| allowed digest printer result |
	allowed := ($0 to: $9), ($a to: $z), ($A to: $Z).
	printer := ALDigestUrlStrategy new.
	digest := #[28 73 254 141 179 78 86 112 213 35 
				68 114 71 214 109 128 51 59 11 139] copy.
	result := printer printKey: digest.
	self assert: result class = ByteString.
	self assert: result size = 24.
	result do: [:char | allowed includes: char]! !

TestCase subclass: #ALLocatorTest
	instanceVariableNames: 'delegate locator'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AL-Tests-Application'!

ALLocatorTest subclass: #ALDigestLocatorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AL-Tests-Application'!

!ALDigestLocatorTest methodsFor: 'running' stamp: 'cwp 10/14/2012 01:37'!
createLocator
	^ ALRestfulLocator digest! !

!ALLocatorTest class methodsFor: 'as yet unclassified' stamp: 'cwp 3/4/2012 12:43'!
isAbstract
	^ self name = #ALLocatorTest! !

!ALLocatorTest methodsFor: 'as yet unclassified' stamp: 'cwp 1/12/2013 00:26'!
= other
	^ self species = other species
		and: [self selector = other selector]! !

!ALLocatorTest methodsFor: 'support' stamp: 'cwp 3/5/2012 21:01'!
asResource
	^ self! !

!ALLocatorTest methodsFor: 'running' stamp: 'cwp 3/4/2012 12:43'!
createLocator
	self subclassResponsibility! !

!ALLocatorTest methodsFor: 'as yet unclassified' stamp: 'cwp 1/12/2013 00:26'!
hash
	^ testSelector hash! !

!ALLocatorTest methodsFor: 'running' stamp: 'cwp 3/4/2012 12:42'!
setUp
	locator := self createLocator! !

!ALLocatorTest methodsFor: 'tests' stamp: 'cwp 10/9/2012 00:15'!
testAtAlias
	| path url |
	path := ALPath / 'alias'.
	url := ALUrl withPath: path.
	locator at: path alias: self.
	self assert: (locator resourceForUrl: url) = self.
	self deny: (locator urlForResource: self) = url.  ! !

!ALLocatorTest methodsFor: 'tests' stamp: 'cwp 10/8/2012 00:20'!
testNotFound
	self
		should: [locator resourceForUrl: (ALUrl / 'plonk')]
		raise: ALNotFound ! !

!ALLocatorTest methodsFor: 'tests' stamp: 'cwp 10/9/2012 00:16'!
testPreseed
	| path resource |
	path := ALPath / 'plonk'.
	locator at: path put: self.
	resource := locator resourceForUrl: path asUrl.
	self assert: resource = self.! !

!ALLocatorTest methodsFor: 'tests' stamp: 'cwp 10/9/2012 00:17'!
testResourceForUrl
	| url resource |
	url := locator urlForResource: self.
	resource := locator resourceForUrl: url.
	self assert: resource = self! !

!ALLocatorTest methodsFor: 'tests' stamp: 'cwp 10/9/2012 00:18'!
testUrlForResource
	| path |
	path := locator urlForResource: self.
	self assert: (path isKindOf: ALUrl)! !

ALLocatorTest subclass: #ALRandomLocatorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AL-Tests-Application'!

!ALRandomLocatorTest methodsFor: 'as yet unclassified' stamp: 'cwp 10/14/2012 01:39'!
createLocator
	^ ALRestfulLocator random! !

ALLocatorTest subclass: #ALTrivialLocatorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'AL-Tests-Application'!

!ALTrivialLocatorTest methodsFor: 'running' stamp: 'cwp 10/14/2012 02:12'!
createLocator
	^ ALRestfulLocator sequential! !
